@@ -2,7 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010 Massachusetts Institute of Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -34,7 +35,7 @@ USA.
   (predicate define accessor))
 
 (define (define-file-folder-type class name predicate)
-  (hash-table/put! file-folder-types
+  (hash-table-set! file-folder-types
 		   class
 		   ((instance-constructor class '(NAME PREDICATE))
 		    name predicate)))
@@ -47,14 +48,14 @@ USA.
    (string-append "File type for " (url->string url))
    (map (lambda (type)
 	  (cons (file-folder-type-name type) type))
-	(hash-table/datum-list file-folder-types))))
+	(hash-table-values file-folder-types))))
 
 (define (url-file-folder-type url)
   (or (file-folder-type (pathname-url-pathname url))
       (error "Unknown folder type:" url)))
 
 (define (file-folder-type pathname)
-  (let loop ((types (hash-table/datum-list file-folder-types)))
+  (let loop ((types (hash-table-values file-folder-types)))
     (and (pair? types)
 	 (if ((file-folder-type-predicate (car types)) pathname)
 	     (car types)
@@ -251,7 +252,7 @@ USA.
 			  initial-value #f)
   (file-modification-count define standard
 			   initial-value #f)
-  (xstring define standard))
+  (string define standard))
 
 (define (file-folder-messages folder)
   (if (eq? 'UNKNOWN (%file-folder-messages folder))
@@ -286,10 +287,10 @@ USA.
 	     (set-file-folder-messages! folder 'UNKNOWN)
 	     (for-each-vector-element messages detach-message!)))))))
 
-(define (discard-file-folder-xstring folder)
+(define (discard-file-folder-string folder)
   (without-interrupts
    (lambda ()
-     (set-file-folder-xstring! folder #f)
+     (set-file-folder-string! folder #f)
      (set-file-folder-file-modification-time! folder #f)
      (set-file-folder-file-modification-count! folder #f))))
 
@@ -427,14 +428,14 @@ USA.
 	(pathname (file-folder-pathname folder)))
     (if (not (and t (= t (file-modification-time pathname))))
 	(begin
-	  (if t (discard-file-folder-xstring folder))
+	  (if t (discard-file-folder-string folder))
 	  (let loop ()
 	    (let ((t (file-modification-time pathname)))
 	      ((imail-ui:message-wrapper "Reading file "
 					 (->namestring pathname))
 	       (lambda ()
-		 (set-file-folder-xstring! folder
-					   (read-file-into-xstring pathname))))
+		 (set-file-folder-string! folder
+					  (read-file-into-string pathname))))
 	      (if (= t (file-modification-time pathname))
 		  (begin
 		    (set-file-folder-file-modification-time! folder t)
@@ -446,11 +447,11 @@ USA.
    folder
    ((imail-ui:message-wrapper "Parsing messages")
     (lambda ()
-      (call-with-input-xstring (file-folder-xstring folder) 0 reader)))))
+      (call-with-input-string (file-folder-string folder) reader)))))
 
 (define-method discard-folder-cache ((folder <file-folder>))
   (discard-file-folder-messages folder)
-  (discard-file-folder-xstring folder))
+  (discard-file-folder-string folder))
 
 (define-method probe-folder ((folder <file-folder>))
   folder
@@ -493,8 +494,8 @@ USA.
 (define-class <file-message> (<message>)
   body)
 
-(define (file-message-xstring message)
-  (file-folder-xstring (message-folder message)))
+(define (file-message-string message)
+  (file-folder-string (message-folder message)))
 
 (define (file-external-ref? object)
   (and (pair? object)
@@ -511,9 +512,9 @@ USA.
       (let ((item (accessor message)))
 	(if (file-external-ref? item)
 	    (operator
-	     (xsubstring (file-message-xstring message)
-			 (file-external-ref/start item)
-			 (file-external-ref/end item)))
+	     (substring (file-message-string message)
+			(file-external-ref/start item)
+			(file-external-ref/end item)))
             item)))))
 
 (define-file-external-message-method message-header-fields
@@ -592,6 +593,6 @@ USA.
 (define (file-folder-internal-headers folder ref)
   (filter! internal-header-field?
 	   (string->header-fields
-	    (xsubstring (file-folder-xstring folder)
-			(file-external-ref/start ref)
-			(file-external-ref/end ref)))))
\ No newline at end of file
+	    (substring (file-folder-string folder)
+		       (file-external-ref/start ref)
+		       (file-external-ref/end ref)))))
\ No newline at end of file
